## Gryffin: An algorithm for Bayesian optimization for categorical variables informed by physical intuition with applications to chemistry

Gryffin is an open source algorithm which implements Bayesian optimization for categorical variables and mixed categorical-continuous parameter domains [1].

... this repository is under construction ... please stay tuned! 


## Installation

##### From source 

Gryffin can be installed from source. 
```
git clone https://github.com/aspuru-guzik-group/gryffin.git
cd gryffin 
python setup.py install
```

### Reference 

[1] Häse, F., Roch, L.M. and Aspuru-Guzik, A., 2020. Gryffin: An algorithm for Bayesian optimization for categorical variables informed by physical intuition with applications to chemistry. arXiv preprint arXiv:2003.12127.

